@@ -1,4 +1,4 @@
-import PostgresConnector
+import connectors.PostgresConnector as PostgresConnector
 from error_handlers import *
 from data import *
 from request import *
